from django.conf import settings

ACTIVE_CLASS = 'active'
if hasattr(settings, 'GASTON_ACTIVE_CLASS'):
    ACTIVE_CLASS = settings.GASTON_ACTIVE_CLASS


class MenuItem:
    def __init__(self, label, url, css_classes='', submenu=None):
        self.label = label
        self.url = url
        self.css_classes = css_classes
        self.submenu = submenu

    def get_active_class(self, request):
        css_class = ''
        if (
            self.url == request.path or
            (self.url != '/' and self.url in request.path)
        ):
            css_class = ACTIVE_CLASS
        return css_class

    def get_css_classes(self):
        return self.css_classes

    def get_all_css_classes(self, request):
        return '%s %s' % \
            (self.get_css_classes(), self.get_active_class(request))



from django import template

register = template.Library()


@register.inclusion_tag('gaston/menu.html', takes_context=True)
def menu(context, menu, depth_count=None):
	depth_count = depth_count + 1 if depth_count is not None else 0

	return {
	    'menu': menu,
	    'request': context['request'],
	    'depth_count': depth_count,
    }


@register.simple_tag(takes_context=True)
def get_item_css_classes(context, item):
    request = context['request']
    return item.get_all_css_classes(request)
